@@ -74,9 +74,9 @@ class ElectraForSequenceClassification(ElectraPreTrainedModel):
 
         # sequence_output = self.pooler(sequence_output)
         first_token_tensor = sequence_output[:, 0]
-        pooled_output = self.dropout(first_token_tensor)
+        # pooled_output = self.dropout(first_token_tensor)
 
-        logits = self.classifier(pooled_output)
+        logits = self.classifier(first_token_tensor)
 
         outputs = (logits,)
 
